rtrfn: A generating function of trapezoidal fuzzy number via uniform distribution
Description
A generating function of trapezoidal fuzzy number via uniform distribution based on Souliotis et al. (2022). See detail in references.
Usage
rtrfn(n, a, c, r, b)
Value
A data frame with two variables, that is, x and mf
Arguments
n
total number of random trapezoidal fuzzy number
a
the left point of trapezoidal fuzzy number
c
the left-middle point of trapezoidal fuzzy number
r
the right-middle point of trapezoidal fuzzy number
b
the right point of trapezoidal fuzzy number
References
Souliotis, G., Alanazi, Y., & Papadopoulos, B. (2022). Construction of fuzzy numbers via cumulative distribution function. Mathematics, 10(18), 3350. https://doi.org/10.3390/math10183350